summaryrefslogtreecommitdiff
path: root/common/keymap.h
diff options
context:
space:
mode:
authortmk <nobody@nowhere>2013-02-13 11:20:47 +0900
committertmk <nobody@nowhere>2013-02-13 11:20:47 +0900
commit63c03dc137afe6600156a060b592662feaad0cdc (patch)
treec69cb8e797ac407028426a96dfebd56cf29211e3 /common/keymap.h
parent48e6d0848cdeac26ffab101ea2ef48e5ac60acd3 (diff)
Change keymap API
Diffstat (limited to 'common/keymap.h')
-rw-r--r--common/keymap.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/common/keymap.h b/common/keymap.h
index 30d73f797f..ee36eab835 100644
--- a/common/keymap.h
+++ b/common/keymap.h
@@ -30,14 +30,23 @@ extern uint8_t current_layer;
extern uint8_t default_layer;
+/* translates key_t to keycode */
+uint8_t keymap_key_to_keycode(uint8_t layer, key_t key);
+/* translates keycode to action */
+action_t keymap_keycode_to_action(uint8_t keycode);
+/* translates Fn keycode to action */
+action_t keymap_fn_to_action(uint8_t keycode);
+
+
/* action for key */
// TODO: should use struct key_t?
action_t keymap_get_action(uint8_t layer, uint8_t row, uint8_t col);
/* user defined special function */
void keymap_call_function(keyrecord_t *record, uint8_t id, uint8_t opt);
+
#ifndef NO_LEGACY_KEYMAP_SUPPORT
/* keycode of key */
uint8_t keymap_get_keycode(uint8_t layer, uint8_t row, uint8_t col);
@@ -30,14 +30,23 @@ extern uint8_t current_layer;
/* action for key */
-// TODO: should use struct key_t?
+// TODO: should use struct key_t? move to action.h?
action_t keymap_get_action(uint8_t layer, uint8_t row, uint8_t col);
/* user defined special function */